@@ -15,6 +15,7 @@ class MemoryCalendarTest : public QObject
 {
     Q_OBJECT
 private Q_SLOTS:
+    void testClose();
     void testValidity();
     void testInvalidTimeZone();
     void testEvents();
@@ -25,6 +26,9 @@ private Q_SLOTS:
     void testRawEvents();
     void testRawEventsForDate();
     void testVisibility();
+    void testNotebookChange();
+    void testDeleteIncidence();
+    void testUpdateIncidence();
 };
 
 #endif
